==> haskell-stm-containers-1.2.1.1-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-2PLmCEBoAPrE81H55Em4hL
key:                  stm-containers-1.2.1.1-2PLmCEBoAPrE81H55Em4hL
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  a4c55b1e08c01107b39e849f57803fe9
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-2PLmCEBoAPrE81H55Em4hL
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-Eg4ALFdsJXmKWlm9gShVHz
    focus-1.0.3.2-BBKFwVZ7aLxKc6tqdaGTG9
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    list-t-1.0.5.7-6HMu2twXA5zBkE80tr321F
    stm-hamt-1.2.1.1-JN9dbzTca24F7oLZ1v84mp transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.1.1-144-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-HDMSUHDkBomL4dX6nqGW13
key:                  stm-containers-1.2.1.1-HDMSUHDkBomL4dX6nqGW13
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  bbd8af003e8dfe4acd92c3263f227b08
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-HDMSUHDkBomL4dX6nqGW13
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-C8YguoMEwBsD5engKreTsc
    focus-1.0.3.2-EgafqfI18jKLjVGmA0bewF
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    list-t-1.0.5.7-6HMu2twXA5zBkE80tr321F
    stm-hamt-1.2.1.1-8nCNyBqOe9m8ubGJputdvt transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
